## 2023.10.3.0 (2023-10-04)

[stubsabot] Bump regex to 2023.10.3 (#10832)

## 2023.8.8.0 (2023-08-10)

[stubsabot] Bump regex to 2023.8.8 (#10553)

Release: https://pypi.org/pypi/regex/2023.8.8
Homepage: https://github.com/mrabarnett/mrab-regex
Repository: https://github.com/mrabarnett/mrab-regex
Diff: https://github.com/mrabarnett/mrab-regex/compare/2023.6.3...2023.8.8

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 15.
 - Total lines of Python code deleted: 10.

## 2023.6.3.1 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 2023.6.3.0 (2023-06-04)

[stubsabot] Bump regex to 2023.6.3 (#10252)

Release: https://pypi.org/pypi/regex/2023.6.3
Homepage: https://github.com/mrabarnett/mrab-regex
Diff: https://github.com/mrabarnett/mrab-regex/compare/2023.5.5...2023.6.3

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 8.
 - Total lines of Python code deleted: 2.

## 2023.5.5.0 (2023-05-04)

[stubsabot] Bump regex to 2023.5.5 (#10138)

Release: https://pypi.org/pypi/regex/2023.5.5
Homepage: https://github.com/mrabarnett/mrab-regex
Diff: https://github.com/mrabarnett/mrab-regex/compare/2023.5.4...2023.5.5

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 2.
 - Total lines of Python code deleted: 2.

## 2023.5.4.0 (2023-05-03)

[stubsabot] Bump regex to 2023.5.4 (#10131)

Release: https://pypi.org/pypi/regex/2023.5.4
Homepage: https://github.com/mrabarnett/mrab-regex
Diff: https://github.com/mrabarnett/mrab-regex/compare/2023.3.23...2023.5.4

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 8.
 - Total lines of Python code deleted: 3.

## 2023.3.23.1 (2023-03-28)

Add defaults for third-party stubs Q-T (#9959)

## 2023.3.23.0 (2023-03-24)

[stubsabot] Bump regex to 2023.3.23 (#9933)

Release: https://pypi.org/pypi/regex/2023.3.23
Homepage: https://github.com/mrabarnett/mrab-regex
Diff: https://github.com/mrabarnett/mrab-regex/compare/2023.03.22...2023.3.23

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 2.
 - Total lines of Python code deleted: 2.

## 2023.3.22.0 (2023-03-23)

[stubsabot] Bump regex to 2023.3.22 (#9927)

Release: https://pypi.org/pypi/regex/2023.3.22
Homepage: https://github.com/mrabarnett/mrab-regex
Diff: https://github.com/mrabarnett/mrab-regex/compare/2022.10.31...2023.03.22

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 6.
 - Total lines of Python code deleted: 8.

## 2022.10.31.6 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 2022.10.31.5 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 2022.10.31.4 (2023-02-07)

Improve pyright verification of third-party test cases in CI (#9650)

Co-authored-by: Avasam <samuel.06@hotmail.com>

## 2022.10.31.3 (2022-11-24)

Add test case for recent `types-regex` regression (#9269)

## 2022.10.31.2 (2022-11-24)

regex: fix type signatures using Scanner (#9266)

## 2022.10.31.1 (2022-11-23)

Mark regex as completed (#9214)

## 2022.10.31.0 (2022-11-01)

[stubsabot] Bump regex to 2022.10.31 (#9050)

Release: https://pypi.org/pypi/regex/2022.10.31
Homepage: https://github.com/mrabarnett/mrab-regex
Diff: https://github.com/mrabarnett/mrab-regex/compare/2022.9.13...2022.10.31

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 3.
 - Total lines of Python code deleted: 2.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 2022.9.13.0 (2022-09-16)

[stubsabot] Bump regex to 2022.9.13 (#8751)

Release: https://pypi.org/project/regex/2022.9.13/
Homepage: https://github.com/mrabarnett/mrab-regex
Diff: https://github.com/mrabarnett/mrab-regex/compare/2022.8.17...2022.9.13

## 2022.8.17.0 (2022-08-19)

[stubsabot] Bump regex to 2022.8.17 (#8562)

Co-authored-by: stubsabot <>

## 2022.7.25.0 (2022-07-29)

[stubsabot] Bump regex to 2022.7.25 (#8432)

Co-authored-by: stubsabot <>

## 2022.7.9.0 (2022-07-15)

[stubsabot] Bump regex to 2022.7.9 (#8300)

Co-authored-by: hauntsaninja <>

## 2022.6.2.0 (2022-06-26)

Bump regex to 2022.6.2 (#8162)

Co-authored-by: AlexWaygood <alex.waygood@gmail.com>

## 2021.11.10.6 (2022-06-21)

`requests`, `regex`: use re-exports instead of assignments in a few places (#8127)

## 2021.11.10.5 (2022-05-11)

regex: accept buffers (#7680)

Similar to #7679

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 2021.11.10.4 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 2021.11.10.3 (2022-02-23)

regex stubs: Add __getitem__ method to Match (#7372)

## 2021.11.10.2 (2022-01-07)

Update pyright (#6840)

## 2021.11.10.0 (2021-12-30)

Add regex stubs (#6713)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: Akuli <akuviljanen17@gmail.com>

